﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MM.Monitor.Client;

namespace MM.Monitor.Plugins
{
    public class UserInputControls : ClientPlugin
    {
        private const string TEXT_INPUT_ID = "StringInput";
        private const string NUMERIC_INPUT_ID = "NumericInput";
        private const string DATE_INPUT_ID = "DateInput";
        private const string TIME_INPUT_ID = "TimeInput";
        private const string DATETIME_INPUT_ID = "DateTimeInput";
        private const string PICKLIST_INPUT_ID = "PickListInput";

        private string stringInputValue = "string value";
        private int numericInputValue = 24;
        private Date dateInputValue = new Date(2010, 10, 4);
        private Time timeInputValue = new Time(10, 21);
        private MM.Monitor.Client.DateTime dateTimeInputValue = new MM.Monitor.Client.DateTime(2011, 10, 11, 12, 13);
        private PickListItem pickListInputValue = pickListItem2;

        private static PickListItem pickListItem1 = new PickListItem(1, "Item 1", "First item");
        private static PickListItem pickListItem2 = new PickListItem(2, "Item 2", "Second item");
        private static PickListItem pickListItem3 = new PickListItem(3, "Item 3", "Third item");

        private static PickListItem[] AllPickListItems = new PickListItem[] { pickListItem1, pickListItem2, pickListItem3 };

        public UserInputControls()
        {
        }

        public override string GetPluginName()
        {
            return "User Input Controls";
        }
        public override string GetPluginDescription()
        {
            return "Demo of user input controls";
        }
        public override Groups GetAdditionalComputerDetails()
        {
            Groups result = new Groups();

            Group group = new Group("Plugin Input Control");
            group.Items.Add(new TextInputItem(TEXT_INPUT_ID, "String", "Current value: " + stringInputValue, stringInputValue));
            group.Items.Add(new NumberInputItem(NUMERIC_INPUT_ID, "Number", "Current value: " + numericInputValue.ToString(), numericInputValue));
            group.Items.Add(new DateInputItem(DATE_INPUT_ID, "Date", "Current value: " + GetDateString(dateInputValue), dateInputValue));
            group.Items.Add(new TimeInputItem(TIME_INPUT_ID, "Time", "Current value: " + GetTimeString(timeInputValue), timeInputValue));
            group.Items.Add(new DateTimeInputItem(DATETIME_INPUT_ID, "Date and Time", "Current value: " + GetDateTimeString(dateTimeInputValue), dateTimeInputValue));

            PickListItems items = new PickListItems();
            items.Add(pickListItem1);
            items.Add(pickListItem2);
            items.Add(pickListItem3);
            group.Items.Add(new PickListInputItem(PICKLIST_INPUT_ID, "Pick", "Current value: " + pickListInputValue.Name, items, pickListInputValue));

            result.Add(group);

            return result;
        }
        
        public override void TextInputValueChanged(string inputId, string inputValue)
        {
            if (inputId == TEXT_INPUT_ID)
            {
                stringInputValue = inputValue;
            }
        }
        public override void NumericInputValueChanged(string inputId, int inputValue)
        {
            if (inputId == NUMERIC_INPUT_ID)
            {
                numericInputValue = inputValue;
            }
        }
        public override void DateInputValueChanged(string inputId, Date inputValue)
        {
            if (inputId == DATE_INPUT_ID)
            {
                dateInputValue = inputValue;
            }
        }
        public override void TimeInputValueChanged(string inputId, Time inputValue)
        {
            if (inputId == TIME_INPUT_ID)
            {
                timeInputValue = inputValue;
            }
        }
        public override void DateTimeInputValueChanged(string inputId, Client.DateTime inputValue)
        {
            if (inputId == DATETIME_INPUT_ID)
            {
                dateTimeInputValue = inputValue;
            }
        }
        public override void PickListInputValueChanged(string inputId, int pickListItemId)
        {
            if (inputId == PICKLIST_INPUT_ID)
            {
                foreach(PickListItem item in AllPickListItems)
                {
                    if (pickListItemId == item.Id)
                    {
                        pickListInputValue = item;
                        break;
                    }
                }
            }
        }
        private static string GetDateString(Date dateInputValue)
        {
            return dateInputValue.Day.ToString() + "-" + dateInputValue.Month.ToString() + "-" + dateInputValue.Year.ToString();
        }
        private static string GetTimeString(Time timeInputValue)
        {
            return timeInputValue.Hour.ToString() + ":" + timeInputValue.Minute.ToString("00");
        }
        private static string GetDateTimeString(MM.Monitor.Client.DateTime dateTimeInputValue)
        {
            return dateTimeInputValue.Day.ToString() + "-" + dateTimeInputValue.Month.ToString() + "-" + dateTimeInputValue.Year.ToString() + " " + dateTimeInputValue.Hour.ToString() + ":" + dateTimeInputValue.Minute.ToString("00");
        }
    }
}
